@@ -523,11 +523,12 @@ metar_finish (SoupSession *session, SoupMessage *msg, gpointer data)
 	    g_warning (_("Failed to get METAR data: %d %s.\n"),
 		       msg->status_code, msg->reason_phrase);
 	}
-	request_done (info, FALSE);
+
+	_gweather_info_request_done (info);
 	return;
     }
 
-    loc = priv->location;
+    loc = &priv->location;
 
     searchkey = g_strdup_printf ("\n%s", loc->code);
     p = strstr (msg->response_body->data, searchkey);
@@ -550,7 +551,7 @@ metar_finish (SoupSession *session, SoupMessage *msg, gpointer data)
     }
 
     priv->valid = success;
-    request_done (info, TRUE);
+    _gweather_info_request_done (info);
 }
 
 /* Read current conditions and fill in info structure */
@@ -566,11 +567,7 @@ metar_start_open (GWeatherInfo *info)
     priv = info->priv;
 
     priv->valid = priv->network_error = FALSE;
-    loc = priv->location;
-    if (loc == NULL) {
-	g_warning (_("WeatherInfo missing location"));
-	return;
-    }
+    loc = &priv->location;
 
     msg = soup_form_request_new (
 	"GET", "http://weather.noaa.gov/cgi-bin/mgetmetar.pl",
